<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling"
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:xalan="http://xml.apache.org/xalan"
	exclude-result-prefixes="sm xalan"
	version="1.0">
<xsl:output method="xml" indent="yes" encoding="UTF-8" omit-xml-declaration="yes"/>
	
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>
	
<xsl:variable name="vCdModel" select="resultatAgent('//codeModel')"/>
		
<xsl:template match="sm:textPrim">
<elt id="{$vCdModel}" lname="{sm:identification/@code}" ns="{sm:identification/@targetNamespace}">
<xsl:apply-templates select="sm:structure"/>
</elt>
<xsl:for-each select="sm:structure/sm:blockTags/sm:tableTag/sm:cellTag">
<eltChild id="{$vCdModel}#cell_{@role}" lname="cell" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:blockTags/*" mode="refs"/>
</eltChild>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:structure">
<eltChild id="{$vCdModel}#para" lname="para" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtAnalyzer" nodeWeight="1">
<inlineElt names="sc:phrase|sc:uLink|sc:inlineStyle|sc:textLeaf"/>
<extraNodeShown names="sc:objectLeaf|sc:emptyLeaf|sc:inlineImg|sc:note"/>
</analyzer>
<xsl:apply-templates select="sm:inlineTags/*"/>
</eltChild>
<xsl:apply-templates select="sm:blockTags/*"/>
</xsl:template>
	
	
	
<xsl:template match="sm:paraTag"/>
	
<xsl:template match="sm:simpleListTag">
<eltChild id="{$vCdModel}#simpleList_{@role}" lname="simpleList" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:itemizedListTag">
<eltChild id="{$vCdModel}#itemizedList_{@role}" lname="itemizedList" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer nodeWeight="1"/>
<xsl:apply-templates/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:orderedListTag">
<eltChild id="{$vCdModel}#orderedList_{@role}" lname="orderedList" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:tableTag">
<eltChild id="{$vCdModel}#table_{@role}" lname="table" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
<xsl:template match="sm:cellTag"/>
	
<xsl:template match="sm:extBlockTag">
<eltChild id="{$vCdModel}#extBlock_{@role}" lname="extBlock" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:emptyBlockTag">
<eltChild id="{$vCdModel}#emptyBlock_{@role}" lname="emptyBlock" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
	
	
	
<xsl:template match="sm:uLinkTag">
<eltChild id="{$vCdModel}#uLink_{@role}" lname="uLink" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtInlineEltAnalyzer"/>
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:inlineTags/*" mode="refs"/>
</eltChild>
</xsl:template>
<xsl:template match="sm:phraseTag">
<eltChild id="{$vCdModel}#phrase_{@role}" lname="phrase" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtInlineEltAnalyzer"/>
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:inlineTags/*" mode="refs"/>
</eltChild>
</xsl:template>
<xsl:template match="sm:inlineStyleTag">
<eltChild id="{$vCdModel}#inlineStyle_{@role}" lname="inlineStyle" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtInlineEltAnalyzer"/>
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:inlineTags/*" mode="refs"/>
</eltChild>
</xsl:template>
<xsl:template match="sm:textLeafTag">
<eltChild id="{$vCdModel}#textLeaf_{@role}" lname="textLeaf" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtInlineEltAnalyzer"/>
<xsl:apply-templates/>
</eltChild>
</xsl:template>
<xsl:template match="sm:inlineImgTag">
<eltChild id="{$vCdModel}#inlineImg_{@role}" lname="inlineImg" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
<xsl:template match="sm:noteTag">
<eltChild id="{$vCdModel}#note" lname="note" ns="http://www.utc.fr/ics/scenari/v3/core">
<eltChild refId="{$vCdModel}"/>
</eltChild>
</xsl:template>
<xsl:template match="sm:objectLeafTag">
<eltChild id="{$vCdModel}#objectLeaf_{@role}" lname="objectLeaf" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
<xsl:template match="sm:emptyLeafTag">
<eltChild id="{$vCdModel}#emptyLeaf_{@role}" lname="emptyLeaf" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
	
	
	
	
<xsl:template match="sm:memberTag">
<eltChild lname="member" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtAnalyzer" nodeWeight="1">
<inlineElt names="sc:phrase|sc:uLink|sc:inlineStyle|sc:textLeaf"/>
<extraNodeShown names="sc:objectLeaf|sc:emptyLeaf|sc:inlineImg|sc:note"/>
</analyzer>
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:inlineTags/*" mode="refs"/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:listItemTag">
<eltChild lname="listItem" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer nodeWeight="1"/>
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:blockTags/*" mode="refs"/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:columnTag">
<eltChild lname="column" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
</eltChild>
</xsl:template>
<xsl:template match="sm:rowTag">
<eltChild lname="row" restrictAttr="role={@role}" ns="http://www.utc.fr/ics/scenari/v3/core">
<xsl:apply-templates/>
<xsl:apply-templates select="../sm:cellTag" mode="refs"/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:titleTag">
<eltChild lname="title" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtAnalyzer">
<inlineElt names="sc:phrase|sc:uLink|sc:inlineStyle|sc:textLeaf"/>
<extraNodeShown names="sc:objectLeaf|sc:emptyLeaf|sc:inlineImg|sc:note"/>
</analyzer>
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:inlineTags/*" mode="refs"/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:captionTag">
<eltChild lname="caption" ns="http://www.utc.fr/ics/scenari/v3/core">
<analyzer type="eu.scenari.diff.bcd.analyzer.mixct.MixCtAnalyzer">
<inlineElt names="sc:phrase|sc:uLink|sc:inlineStyle|sc:textLeaf"/>
<extraNodeShown names="sc:objectLeaf|sc:emptyLeaf|sc:inlineImg|sc:note"/>
</analyzer>
<xsl:apply-templates/>
<xsl:apply-templates select="/*/sm:structure/sm:inlineTags/*" mode="refs"/>
</eltChild>
</xsl:template>
	
<xsl:template match="sm:meta">
<eltChild refId="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:template>


	
	
<xsl:template match="sm:paraTag" mode="refs">
<eltChild refId="{$vCdModel}#para"/>
</xsl:template>
<xsl:template match="sm:simpleListTag" mode="refs">
<eltChild refId="{$vCdModel}#simpleList_{@role}"/>
</xsl:template>
<xsl:template match="sm:itemizedListTag" mode="refs">
<eltChild refId="{$vCdModel}#itemizedList_{@role}"/>
</xsl:template>
<xsl:template match="sm:orderedListTag" mode="refs">
<eltChild refId="{$vCdModel}#orderedList_{@role}"/>
</xsl:template>
<xsl:template match="sm:tableTag" mode="refs">
<eltChild refId="{$vCdModel}#table_{@role}"/>
</xsl:template>
<xsl:template match="sm:cellTag" mode="refs">
<eltChild refId="{$vCdModel}#cell_{@role}"/>
</xsl:template>
<xsl:template match="sm:extBlockTag" mode="refs">
<eltChild refId="{$vCdModel}#extBlock_{@role}"/>
</xsl:template>
<xsl:template match="sm:emptyBlockTag" mode="refs">
<eltChild refId="{$vCdModel}#emptyBlock_{@role}"/>
</xsl:template>
	
	
	
	
<xsl:template match="sm:uLinkTag" mode="refs">
<eltChild refId="{$vCdModel}#uLink_{@role}"/>
</xsl:template>
<xsl:template match="sm:phraseTag" mode="refs">
<eltChild refId="{$vCdModel}#phrase_{@role}"/>
</xsl:template>
<xsl:template match="sm:inlineStyleTag" mode="refs">
<eltChild refId="{$vCdModel}#inlineStyle_{@role}"/>
</xsl:template>
<xsl:template match="sm:textLeafTag" mode="refs">
<eltChild refId="{$vCdModel}#textLeaf_{@role}"/>
</xsl:template>	
<xsl:template match="sm:noteTag" mode="refs">
<eltChild refId="{$vCdModel}#note"/>
</xsl:template>
<xsl:template match="sm:objectLeafTag" mode="refs">
<eltChild refId="{$vCdModel}#objectLeaf_{@role}"/>
</xsl:template>
<xsl:template match="sm:emptyLeafTag" mode="refs">
<eltChild refId="{$vCdModel}#emptyLeaf_{@role}"/>
</xsl:template>
<xsl:template match="sm:inlineImgTag" mode="refs">
<eltChild refId="{$vCdModel}#inlineImg_{@role}"/>
</xsl:template>
	
<xsl:template match="*" mode="refs"/>
<xsl:template match="text()|@*" mode="refs"/>
	
<xsl:template match="*"/>
<xsl:template match="text()|@*"/>
</xsl:stylesheet>